/**
 * PANDA 3D SOFTWARE
 * Copyright (c) Carnegie Mellon University.  All rights reserved.
 *
 * All use of this software is subject to the terms of the revised BSD
 * license.  You should have received a copy of this license along
 * with this source code in a file named "LICENSE."
 *
 * @file pStatCollectorForwardBase.cxx
 * @author drose
 * @date 2006-10-30
 */

#include "pStatCollectorForwardBase.h"

/**
 *
 */
PStatCollectorForwardBase::
~PStatCollectorForwardBase() {
}
